@@ -33,8 +33,10 @@ class MonitorThread(threading.Thread):
                 for server_name, handle in self.pool.handle_dict.items():
                     if handle.is_connected:
                         try:
-                            handle.sendSync('til 1')
-                        except ConnectionError:
+                            with handle.lock:
+                                handle.sendSync('til 1')
+                                logger.debug(server_name + ' heartbeat success')
+                        except Exception as e:
                             logger.warning(server_name + ' heartbeat failed')
                             handle.is_connected = False
                     else:
@@ -66,7 +68,6 @@ class ConnectionPool:
                 if cls._instance is None:
                     cls._instance = super(ConnectionPool, cls).__new__(cls)
                     cls._instance.handle_dict = {}
-                    cls.start_monitor_thread()
         return cls._instance
 
     def __init__(self, server_list=None):
@@ -75,6 +76,7 @@ class ConnectionPool:
         for server in server_list:
             if server.name not in self._instance.handle_dict.keys():
                 self.create_connection(server)
+        self.start_monitor_thread()
 
     @staticmethod
     def start_monitor_thread():
@@ -85,10 +87,11 @@ class ConnectionPool:
         conn = QHandle(server)
         self.handle_dict[server.name] = conn
         try:
+            logger.debug('Try connect to ' + server.name)
             with conn.lock:
                 conn.open()
-        except (ConnectionError, TimeoutError):
-            logger.error('Connect to {} failed'.format(server.name))
+        except Exception as e:
+            logger.error('Connect to {} failed: '.format(server.name, e.args))
             conn.is_connected = False
         else:
             conn.is_connected = True
@@ -114,8 +117,11 @@ class Query:
                     result = self.conn.sendSync(query, *parameters, **options)
             except Exception as e:
                 log_str = "DB[{}] error: {}, query: {}, params: {}, options: {}"
-                logger.error(log_str.format(self.server.name, e.args[0], query, parameters, options))
-            return result
+                logger.error(log_str.format(self.server.name, e.args, query, parameters, options))
+        else:
+            log_str = "DB[{}] error: Invalid handle"
+            logger.error(log_str.format(self.server.name))
+        return result
 
     @staticmethod
     def to_sym(s):
